@@ -8,6 +8,7 @@ Defines:
     InvalidCountryCode,
     InvalidSwiftCode,
 """
+# import
 from .dataloader import (
     InvalidCountryCode,
     InvalidSwiftCode,
@@ -20,11 +21,15 @@ from .dataloader import (
 
 
 __all__ = [
-    InvalidCountryCode,
-    InvalidSwiftCode,
-    build_path,
-    countrycode_from_swiftcode,
-    isvalid_swiftcode,
-    load_country_data,
-    lookup_swiftcode,
+    "InvalidCountryCode",
+    "InvalidSwiftCode",
+    "build_path",
+    "countrycode_from_swiftcode",
+    "isvalid_swiftcode",
+    "load_country_data",
+    "lookup_swiftcode",
 ]
+
+__version__ = "0.1.0"
+
+__author__ = "Tralah M Brian <https://github.com/TralahM>"
